@@ -649,7 +649,7 @@ int check_net_dev_reg(struct activity *a, int curr, int ref, int pos)
 				 * relevant counter has met an overflow condition, and that
 				 * the interface was not unregistered, which is all the
 				 * more plausible that the previous value for the counter
-				 * was > ULONG_MAX/2.
+				 * was > ULLONG_MAX/2.
 				 * NB: the average value displayed will be wrong in this case...
 				 *
 				 * If such an overflow is detected, just set the flag. There is no
@@ -661,22 +661,22 @@ int check_net_dev_reg(struct activity *a, int curr, int ref, int pos)
 
 				if ((sndc->rx_bytes   < sndp->rx_bytes)   &&
 				    (sndc->rx_packets > sndp->rx_packets) &&
-				    (sndp->rx_bytes   > (~0UL >> 1))) {
+				    (sndp->rx_bytes   > (~0ULL >> 1))) {
 					ovfw = TRUE;
 				}
 				if ((sndc->tx_bytes   < sndp->tx_bytes)   &&
 				    (sndc->tx_packets > sndp->tx_packets) &&
-				    (sndp->tx_bytes   > (~0UL >> 1))) {
+				    (sndp->tx_bytes   > (~0ULL >> 1))) {
 					ovfw = TRUE;
 				}
 				if ((sndc->rx_packets < sndp->rx_packets) &&
 				    (sndc->rx_bytes   > sndp->rx_bytes)   &&
-				    (sndp->rx_packets > (~0UL >> 1))) {
+				    (sndp->rx_packets > (~0ULL >> 1))) {
 					ovfw = TRUE;
 				}
 				if ((sndc->tx_packets < sndp->tx_packets) &&
 				    (sndc->tx_bytes   > sndp->tx_bytes)   &&
-				    (sndp->tx_packets > (~0UL >> 1))) {
+				    (sndp->tx_packets > (~0ULL >> 1))) {
 					ovfw = TRUE;
 				}
 
